@@ -2,7 +2,7 @@
  * ====                   FRACTAL GRAPHICS GENERATOR                     ====
  * ==========================================================================
  *
- * Copyright (C) 2003-2021 by Thomas Dreibholz
+ * Copyright (C) 2003-2025 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,23 +25,53 @@
 #include <qcolor.h>
 
 
-SimpleHSV* SimpleHSV::Registration = new SimpleHSV();
+const QString SimpleHSV::Identifier(QStringLiteral("SimpleHSV"));
+const QString SimpleHSV::Description(QStringLiteral("Simple HSV"));
+const bool SimpleHSV::Registered =
+   ColorSchemeInterface::registerClass(
+      SimpleHSV::Identifier,
+      SimpleHSV::Description,
+      &SimpleHSV::makeNewInstance
+   );
 
 
-SimpleHSV::SimpleHSV(const char* identifier, const char* name)
-   : ColorSchemeInterface(identifier, name)
+// ###### Constructor #######################################################
+SimpleHSV::SimpleHSV()
 {
 }
 
 
+// ###### Destructor ########################################################
 SimpleHSV::~SimpleHSV()
 {
 }
 
 
+// ###### Get identifier ####################################################
+const QString& SimpleHSV::getIdentifier() const
+{
+   return SimpleHSV::Identifier;
+}
+
+
+// ###### Get description ###################################################
+const QString& SimpleHSV::getDescription() const
+{
+   return SimpleHSV::Description;
+}
+
+
+// ###### Create new instance ###############################################
+ColorSchemeInterface* SimpleHSV::makeNewInstance()
+{
+   return new SimpleHSV();
+}
+
+
+// ###### Get color for value ###############################################
 unsigned int SimpleHSV::getColor(const unsigned int value)
 {
    QColor color;
    color.setHsv((value % 72) * 5, 255, 255);
-   return(color.rgb());
+   return color.rgb();
 }
